@@ -4,19 +4,32 @@ import sys
 import tempfile
 import logging
 from django.core import serializers, management
-from django.db import (models, transaction, router, DEFAULT_DB_ALIAS,
-        DatabaseError, IntegrityError)
-from avocado.models import DataField, DataConcept, DataConceptField, DataCategory
+from django.core.exceptions import ImproperlyConfigured
+from django.db import models, transaction, router, DEFAULT_DB_ALIAS, \
+    DatabaseError, IntegrityError
+from avocado.models import DataField, DataConcept, DataConceptField, \
+    DataCategory
 
 FIXTURE_FORMAT = 'json'
 FIXTURE_FILENAME_RE = re.compile(r'^[0-9]{4}_[0-9a-zA-Z_]+(\.json)$')
 
 MIGRATION_MODEL_LABELS = ('avocado.datafield', 'avocado.dataconcept',
-    'avocado.dataconceptfield', 'avocado.datacategory')
+                          'avocado.dataconceptfield', 'avocado.datacategory')
 
 log = logging.getLogger(__name__)
 
 
+def _check_app():
+    from avocado.conf import settings
+    app_name = settings.METADATA_MIGRATION_APP
+    if not app_name or not models.get_app(app_name.split('.')[-1]):
+        raise ImproperlyConfigured('{0} is not a valid app name. The '
+                                   'backup/migration API requires '
+                                   'METADATA_MIGRATION_APP to be a valid '
+                                   'app name to be used.'
+                                   .format(settings.METADATA_MIGRATION_APP))
+
+
 def _fixture_filenames(dirname):
     filenames = []
     for f in os.listdir(dirname):
@@ -36,15 +49,18 @@ def next_fixture_name(name, dirname):
 
 
 def full_fixture_path(name):
-    return u'{0}.{1}'.format(os.path.join(get_fixture_dir(), name), FIXTURE_FORMAT)
+    return u'{0}.{1}'.format(os.path.join(get_fixture_dir(), name),
+                             FIXTURE_FORMAT)
 
 
 def get_fixture_dir():
     from avocado.conf import settings
+    _check_app()
+
     fixture_dir = settings.METADATA_FIXTURE_DIR
     if fixture_dir:
         return fixture_dir
-    app = models.get_app(settings.METADATA_MIGRATION_APP)
+    app = models.get_app(settings.METADATA_MIGRATION_APP.split('.')[-1])
     if hasattr(app, '__path__'):
         # It's a 'models/' subpackage
         app_dir = os.path.dirname(os.path.dirname(app.__file__))
@@ -62,14 +78,14 @@ def create_fixture(name, using=DEFAULT_DB_ALIAS, silent=False):
         fixture_path = full_fixture_path(name)
     with open(fixture_path, 'w') as fout:
         management.call_command('dumpdata', *MIGRATION_MODEL_LABELS,
-            database=using, stdout=fout)
+                                database=using, stdout=fout)
     if not silent:
         log.info(u'Created fixture {0}'.format(name))
 
 
 def create_temp_fixture(*args, **kwargs):
     "Creates a fixture to a temporary file."
-    fh, path = tempfile.mkstemp() 
+    fh, path = tempfile.mkstemp()
     create_fixture(path, *args, **kwargs)
     return path
 
@@ -93,10 +109,9 @@ def load_fixture(name, using=DEFAULT_DB_ALIAS):
                         obj.save(using=using)
                     except (DatabaseError, IntegrityError), e:
                         transaction.rollback(using)
-                        msg = u'Could not load {app_label}.{object_name}(pk={pk}): {error_msg}'\
-                            .format(app_label=obj.object._meta.app_label,
-                                object_name=obj.object._meta.object_name,
-                                pk=obj.object.pk, error_msg=e)
+                        msg = u'Could not load {0}.{1}(pk={2}): {3}'.format(
+                            obj.object._meta.app_label,
+                            obj.object._meta.object_name, obj.object.pk, e)
                         raise e.__class__, e.__class__(msg), sys.exc_info()[2]
             transaction.commit(using)
     log.info(u'Loaded data from fixture {0}'.format(name))
@@ -116,19 +131,24 @@ def safe_load(name, backup_path=None, using=DEFAULT_DB_ALIAS):
     the new fixture and falls back to the backup fixture if the load fails for
     any reason.
     """
+    _check_app()
+
     with transaction.commit_manually(using):
-        # Create the backup fixture 
+        # Create the backup fixture
         if backup_path:
-            create_fixture(os.path.abspath(backup_path), using=using, silent=True)
+            create_fixture(os.path.abspath(backup_path), using=using,
+                           silent=True)
         else:
             backup_path = create_temp_fixture(using=using, silent=True)
-        log.info(u'Backup fixture written to {0}'.format(os.path.abspath(backup_path)))
+        log.info(u'Backup fixture written to {0}'.format(os.path.abspath(
+            backup_path)))
         delete_metadata(using=using)
         try:
             load_fixture(name, using=using)
         except (DatabaseError, IntegrityError):
             transaction.rollback(using)
-            log.error(u'Fixture load failed, reverting from backup: {0}'.format(backup_path))
+            log.error(u'Fixture load failed, reverting from backup: {0}'
+                      .format(backup_path))
             load_fixture(backup_path, using=using)
             raise
         transaction.commit(using)
