@@ -2,16 +2,49 @@ import logging
 from django.db import models
 from django.db.models import Q
 from django.db import transaction
-from django.conf import settings as django_settings
+from django.conf import settings
 from django.db.models.manager import ManagerDescriptor
 from django.core.exceptions import ImproperlyConfigured
-from avocado.conf import OPTIONAL_DEPS, requires_dep, settings
+from avocado.conf import OPTIONAL_DEPS, requires_dep
 from avocado.core.managers import PublishedManager, PublishedQuerySet
 
 
 logger = logging.getLogger(__name__)
 
 
+class DataSearchMixin(models.Manager):
+    @requires_dep('haystack')
+    def search(self, content, queryset=None, max_results=None, partial=False,
+               using=None):
+        from haystack.query import RelatedSearchQuerySet
+        from haystack.inputs import AutoQuery
+        # Limit to the model bound to this manager, e.g. DataConcept.
+        # `load_all` ensures a single database hit when loading the objects
+        # that match
+        sqs = RelatedSearchQuerySet().models(self.model).load_all()
+
+        # If a non-default backend is being used, set which backend is to
+        # be used.
+        if using is not None:
+            sqs = sqs.using(using)
+
+        if partial:
+            # Autocomplete only works with N-gram fields
+            sqs = sqs.autocomplete(text_auto=content)
+        else:
+            # Automatically handles advanced search syntax for negations and
+            # quoted strings
+            sqs = sqs.filter(text=AutoQuery(content))
+
+        if queryset is not None:
+            sqs = sqs.load_all_queryset(self.model, queryset)
+
+        if max_results:
+            return sqs[:max_results]
+
+        return sqs
+
+
 class DataFieldQuerySet(PublishedQuerySet):
     def published(self, user=None, perm='avocado.view_datafield'):
         """Fields can be restricted to one or more sites, so the published
@@ -24,7 +57,7 @@ class DataFieldQuerySet(PublishedQuerySet):
 
         # All published concepts associated with the current site
         # (or no site)
-        sites = Q(sites=None) | Q(sites__id=django_settings.SITE_ID)
+        sites = Q(sites=None) | Q(sites__id=settings.SITE_ID)
         published = published.filter(sites)
 
         if user:
@@ -41,6 +74,8 @@ class DataConceptQuerySet(PublishedQuerySet):
         """Concepts can be restricted to one or more sites, so the published
         method is extended to support filtering by site. In addition, concepts
         should not be visible if their associated fields are not all available.
+        Also, concepts with an unpublished category are not visible. Finally,
+        concepts with no fields are not considered visible.
         """
         published = super(DataConceptQuerySet, self).published()
 
@@ -49,9 +84,14 @@ class DataConceptQuerySet(PublishedQuerySet):
 
         # All published concepts associated with the current site
         # (or no site)
-        sites = Q(sites=None) | Q(sites__id=django_settings.SITE_ID)
+        sites = Q(sites=None) | Q(sites__id=settings.SITE_ID)
         published = published.filter(sites)
 
+        # All published concepts with a non-empty category must have the
+        # category published as well in order for it to be visible.
+        category_published = Q(category=None) | Q(category__published=True)
+        published = published.filter(category_published)
+
         # Concepts that contain at least one unpublished or archived datafield
         # are removed from the set to prevent exposing unprepared data
         from avocado.models import DataField
@@ -69,7 +109,8 @@ class DataConceptQuerySet(PublishedQuerySet):
             fields_q = fields_q | Q(pk__in=restricted_fields)
 
         shadowed = DataField.objects.filter(fields_q)
-        concepts = published.exclude(fields__in=shadowed).distinct()
+        concepts = published.exclude(fields__in=shadowed) \
+            .exclude(fields=None).distinct()
         return concepts
 
 
@@ -86,7 +127,7 @@ class DataFieldManagerDescriptor(ManagerDescriptor):
         return super(DataFieldManagerDescriptor, self).__get__(instance, type)
 
 
-class DataFieldManager(PublishedManager):
+class DataFieldManager(PublishedManager, DataSearchMixin):
     "Manager for the `DataField` model."
 
     def contribute_to_class(self, model, name):
@@ -120,48 +161,12 @@ class DataFieldManager(PublishedManager):
             values = [app_name, model_name, field_name]
         return queryset.get(**dict(zip(keys, values)))
 
-    @requires_dep('haystack')
-    def search(self, content, queryset=None, max_results=None, partial=False):
-        if not settings.FIELD_SEARCH_ENABLED:
-            logger.warn('DataField search not enabled')
-            return []
 
-        from haystack.query import RelatedSearchQuerySet
-        sqs = RelatedSearchQuerySet().models(self.model).load_all()
-        if partial:
-            sqs = sqs.autocomplete(text_auto=content)
-        else:
-            sqs = sqs.auto_query(content)
-        if queryset is not None:
-            sqs = sqs.load_all_queryset(self.model, queryset)
-        if max_results:
-            return sqs[:max_results]
-        return sqs
-
-
-class DataConceptManager(PublishedManager):
+class DataConceptManager(PublishedManager, DataSearchMixin):
     "Manager for the `DataConcept` model."
     def get_query_set(self):
         return DataConceptQuerySet(self.model, using=self._db)
 
-    @requires_dep('haystack')
-    def search(self, content, queryset=None, max_results=None, partial=False):
-        if not settings.CONCEPT_SEARCH_ENABLED:
-            logger.warn('DataConcept search not enabled')
-            return []
-
-        from haystack.query import RelatedSearchQuerySet
-        sqs = RelatedSearchQuerySet().models(self.model).load_all()
-        if partial:
-            sqs = sqs.autocomplete(text_auto=content)
-        else:
-            sqs = sqs.auto_query(content)
-        if queryset is not None:
-            sqs = sqs.load_all_queryset(self.model, queryset)
-        if max_results:
-            return sqs[:max_results]
-        return sqs
-
     @transaction.commit_on_success
     def create_from_field(self, field, save=True, **kwargs):
         """Derives a DataConcept from this DataField's descriptors. Additional
